#!/bin/bash
name=$1
bdir=$2
password=$3
gwtype=$4
##decrypt and decompress keys and certs
if [ -e $bdir/enc.tar.enc ]; then
    cd $bdir
    openssl enc -d -aes-256-cbc -a -in enc.tar.enc -out enc.tar -pass pass:$password
    tar -xvf enc.tar
    rm enc.tar
    cp -av $bdir/enc/* /data/dtn/certs/
    cp /data/dtn/certs/accounts/pwdenc.key /data/apps/DTNmailex/etc/
    echo "populating certs and keys at /data/dtn/certs/"
else
    echo "$bdir/enc does not exist"
fi

##build libcgic
if [ -e /data/apps/cgic205.tar ]; then
    cd /data/apps
    tar -xvf cgic205.tar
    rm cgic205.tar
    cd /data/apps/cgic205
    echo "building cgic"
    make
    make install
    else 
    echo "/data/apps/cgic205.tar.gz does not exist"
fi

##build LTPlib
if [ -e /data/apps/LTPlib ]; then
    cd /data/apps/LTPlib
    echo "building LTPlib"
    rm config.* depcomp
    sudo -u dtnuser ./bootstrap
    sudo -u dtnuser make
else
    echo "/data/apps/LTPlib does not exist"
fi

##build oasys
if [ -e /data/apps/oasys ]; then
    cd /data/apps/oasys
    echo "building oasys"
    sudo -u dtnuser ./build_configure
    sudo -u dtnuser ./configure
    sudo -u dtnuser make
else 
    echo "/data/apps/oasys does not exist"
fi

##build DTN2
## to  build bsp and ltp replace "sudo -u dtnuser ./configure"   with "sudo -u dtnuser ./configure --with-bsp --with-ltp"

if [ -e /data/apps/DTN2 ]; then
    cd /data/apps/DTN2
echo "building DTN2"
    sudo -u dtnuser ./build_configure
    sudo -u dtnuser ./configure 
    sudo -u dtnuser make

    rm /etc/dtn.conf
    $bdir/scripts/./generate-dtn-conf.tcl >/etc/dtn.conf
    cd /data/apps/DTN2
    touch /var/log/dtn/dtnd.log

tools/./install.sh <<EOF
dtnuser

EOF
   sudo -u dtnuser dtnd --init-db -c /etc/dtn.conf
   chown -R dtnuser:dtnuser /data/dtn/storage /data/dtn/payload /data/dtn/log
   chown dtnuser:dtnuser /var/log/dtn/dtnd.log

else
    echo "/data/apps/DTN2 does not exist"
fi

    ## build libphidgets
    if [ -e /data/apps/Phidgetlinux_2.1.6.20100428.tar.gz ]; then
        cd /data/apps
        tar -xvf Phidgetlinux_2.1.6.20100428.tar.gz
        cd /data/apps/Phidgetlinux/phidget21
        make
        make install
        rm /data/apps/Phidgetlinux_2.1.6.20100428.tar.gz
    else
        echo "/data/apps/Phidgetlinux_2.1.6.20100428.tar.gz does not exist"
    fi
    ##build pbm
    if [ -e /data/apps/pbm ]; then
        /etc/init.d/pbm stop

        cd /data/apps/pbm
        for script in   stopproc.sh \
                        stbyshort.sh \
                        stbylong.sh \
                        sleeprtc.sh ; do
        
            cp ./$script /etc/
            chmod +x   /etc/$script
            chown root /etc/$script
            chgrp root /etc/$script
            echo "Copied $script to /etc ..."
        done
                        
        cp ./pbm   /etc/init.d
        chmod +x   /etc/init.d/pbm
        chown root /etc/init.d/pbm
        chgrp root /etc/init.d/pbm
        echo "Copied pbm to /etc/init.d ..."

        echo "building pbm"
        make all
        cp ./pbmd  /usr/sbin
        chmod +x   /usr/sbin/pbmd
        chown root /usr/sbin/pbmd
        chgrp root /usr/sbin/pbmd
        echo "Copied pbmd to /usr/sbin ..."
        
        echo "Starting pbm ..."
        /etc/init.d/pbm start

    else
        echo "/data/apps/pbm does not exist"
    fi


if [ "$name" == "n4crouter" ]; then
    ##build mod_auth_forms
    if [ -e /data/www/private/HTMLrequester/mod_auth_form-2.05 ]; then
	cd /data/www/private/HTMLrequester/mod_auth_form-2.05
	echo "building mod_auth_form-2.05"
	set -x
	export APACHE2_INCLUDE='/usr/include/apache2'
	export APR1_INCLUDE=/usr/include/apr-1.0
	aclocal \
	&& autoconf \
	&& libtoolize \
	&& automake \
	&& ./configure

	#edit /data/apps/HTMLrequester/mod_auth_form-2.05/src/Makefile.am and add compiler directive output from apr-1-config --cppflags
	## Add the required include files to the compiler
	FLAG=`apr-1-config --cppflags`
	echo "AM_CPPFLAGS =$FLAG" >>/data/www/private/HTMLrequester/mod_auth_form-2.05/src/Makefile.am
	make
	make install
	./libtool --finish /usr/local/lib

	cd /etc/apache2/mods-enabled
	if [ -e /etc/apache2/mods-available/auth_form.load ]; then
	    rm /etc/apache2/mods-available/auth_form.load
	fi
	if [ -e /etc/apache2/mods-available/rewrite.load ]; then
	    rm /etc/apache2/mods-available/rewrite.load
	fi
	touch /etc/apache2/mods-available/auth_form.load
	touch /etc/apache2/mods-available/rewrite.load
	echo "LoadModule auth_form_module /usr/lib/apache2/modules/mod_auth_form.so" >>/etc/apache2/mods-available/auth_form.load
	echo "LoadModule rewrite_module /usr/lib/apache2/modules/mod_rewrite.so" >>/etc/apache2/mods-available/rewrite.load
	ln -s ../mods-available/auth_form.load auth_form.load
	ln -s ../mods-available/rewrite.load rewrite.load
	ln -s ../mods-available/mime_magic.load mime_magic.load
	ln -s ../mods-available/mime_magic.conf mime_mime.conf
	ln -s ../mods-available/ssl.conf ssl.conf
	ln -s ../mods-available/ssl.load ssl.load
	ln -s /etc/squirrelmail/apache.conf /etc/apache2/conf.d/squirrelmail.conf
    else
	echo "/data/www/private/HTMLrequester/mod_auth_form-2.05 does not exist"
    fi


    ## build libphidgets
    if [ -e /data/apps/Phidgetlinux_2.1.6.20100428.tar.gz ]; then
	cd /data/apps
	tar -xvf Phidgetlinux_2.1.6.20100428.tar.gz
	cd /data/apps/Phidgetlinux/phidget21
	make
	make install
	rm /data/apps/Phidgetlinux_2.1.6.20100428.tar.gz
    else
	echo "/data/apps/Phidgetlinux_2.1.6.20100428.tar.gz does not exist"
    fi
    ##build pbm
    if [ -e /data/apps/pbm ]; then
        /etc/init.d/pbm stop

        cd /data/apps/pbm
        for script in   stopproc.sh \
                        stbyshort.sh \
                        stbylong.sh \
                        sleeprtc.sh ; do

            cp ./$script /etc/
            chmod +x   /etc/$script
            chown root /etc/$script
            chgrp root /etc/$script
            echo "Copied $script to /etc ..."
        done

        cp ./pbm   /etc/init.d
        chmod +x   /etc/init.d/pbm
        chown root /etc/init.d/pbm
        chgrp root /etc/init.d/pbm
        echo "Copied pbm to /etc/init.d ..."

        echo "building pbm"
        make all
        cp ./pbmd  /usr/sbin
        chmod +x   /usr/sbin/pbmd
        chown root /usr/sbin/pbmd
        chgrp root /usr/sbin/pbmd
        echo "Copied pbmd to /usr/sbin ..."
        
        echo "Starting pbm ..."
        /etc/init.d/pbm start

    else
        echo "/data/apps/pbm does not exist"
    fi

    ##build DTNmail
    if [ -e /data/apps/DTNmailex/dtnmail ]; then
	cd /data/apps/DTNmailex/dtnmail
	echo "building DTNmail"
	cp postfix/main.cf /etc/postfix/
	cp postfix/master.cf /etc/postfix/
	cp postfix/aliases /etc/postfix/
	cp postfix/aliases.db /etc/postfix/
	cp postfix/transport /etc/postfix/
	cp postfix/transport.db /etc/postfix/
	cp postfix/virtual.db /etc/postfix/
	cp postfix/dynamicmaps.cf /etc/postfix/
	cp dovecot/dovecot.conf /etc/dovecot/
	cp dovecot/passwd.default /etc/dovecot/passwd
	chmod 755 /etc/postfix/main.cf
	cp etc/init.d/dtnmail* /etc/init.d/
	chmod 755 /etc/init.d/dtnmail*
	cp usr/local/bin/dtnmail* /usr/local/bin/
	chmod 755 /usr/local/bin/dtnmail*
	cp etc/squirrelmail/config.php /etc/squirrelmail/
	cp usr/share/squirrelmail/images/n4c-logo.png /usr/share/squirrelmail/images/
	touch /var/log/dovecot.log /var/log/dovecot-info.log
	chmod 666 /var/log/dovecot.log
	chmod 666 /var/log/dovecot-info.log
	chmod 755 /data/apps/DTNmailex/bin/*.php
        chown -R dtnuser:dtnuser /data/apps/DTNmailex/etc/*	
    else
	echo "/data/apps/DTNmailex does not exist"
    fi

elif [ "$name" == "n4cgateway" ]; then
    if ["$gwtype" == "gateway-basic" ]; then
    ## build libphidgets
    if [ -e /data/apps/Phidgetlinux_2.1.6.20100428.tar.gz ]; then
        cd /data/apps
        tar -xvf Phidgetlinux_2.1.6.20100428.tar.gz
        cd /data/apps/Phidgetlinux/phidget21
        make
        make install
        rm /data/apps/Phidgetlinux_2.1.6.20100428.tar.gz
    else
        echo "/data/apps/Phidgetlinux_2.1.6.20100428.tar.gz does not exist"
    fi
    ##build pbm
    if [ -e /data/apps/pbm ]; then
        /etc/init.d/pbm stop

        cd /data/apps/pbm
        for script in   stopproc.sh \
                        stbyshort.sh \
                        stbylong.sh \
                        sleeprtc.sh ; do

            cp ./$script /etc/
            chmod +x   /etc/$script
            chown root /etc/$script
            chgrp root /etc/$script
            echo "Copied $script to /etc ..."
        done

        cp ./pbm   /etc/init.d
        chmod +x   /etc/init.d/pbm
        chown root /etc/init.d/pbm
        chgrp root /etc/init.d/pbm
        echo "Copied pbm to /etc/init.d ..."

        echo "building pbm"
        make all
        cp ./pbmd  /usr/sbin
        chmod +x   /usr/sbin/pbmd
        chown root /usr/sbin/pbmd
        chgrp root /usr/sbin/pbmd
        echo "Copied pbmd to /usr/sbin ..."
        
        echo "Starting pbm ..."
        /etc/init.d/pbm start

    else
        echo "/data/apps/pbm does not exist"
    fi

	echo "all source built for $gwtype"
    elif [ "$gwtype" == "gateway-router" ]; then
	##build mod_auth_forms
	if [ -e /data/www/private/HTMLrequester/mod_auth_form-2.05 ]; then
	    cd /data/www/private/HTMLrequester/mod_auth_form-2.05
	    echo "building mod_auth_form-2.05"
	    set -x
	    export APACHE2_INCLUDE='/usr/include/apache2'
	    export APR1_INCLUDE=/usr/include/apr-1.0
	    aclocal \
	    && autoconf \
	    && libtoolize \
	    && automake \
	    && ./configure

	    #edit /data/apps/HTMLrequester/mod_auth_form-2.05/src/Makefile.am and add compiler directive output from apr-1-config --cppflags
	    ## Add the required include files to the compiler
	    FLAG=`apr-1-config --cppflags`
	    echo "AM_CPPFLAGS =$FLAG" >>/data/www/private/HTMLrequester/mod_auth_form-2.05/src/Makefile.am
	    make
	    make install
	    ./libtool --finish /usr/local/lib

	    cd /etc/apache2/mods-enabled
		if [ -e /etc/apache2/mods-available/auth_form.load ]; then
		    rm /etc/apache2/mods-available/auth_form.load
		fi
		if [ -e /etc/apache2/mods-available/rewrite.load ]; then
		    rm /etc/apache2/mods-available/rewrite.load
		fi
	    touch /etc/apache2/mods-available/auth_form.load
	    touch /etc/apache2/mods-available/rewrite.load
	    echo "LoadModule auth_form_module /usr/lib/apache2/modules/mod_auth_form.so" >>/etc/apache2/mods-available/auth_form.load
	    echo "LoadModule rewrite_module /usr/lib/apache2/modules/mod_rewrite.so" >>/etc/apache2/mods-available/rewrite.load
	    ln -s ../mods-available/auth_form.load auth_form.load
	    ln -s ../mods-available/rewrite.load rewrite.load
	    ln -s ../mods-available/mime_magic.load mime_magic.load
	    ln -s ../mods-available/mime_magic.conf mime_mime.conf
	    ln -s ../mods-available/ssl.conf ssl.conf
	    ln -s ../mods-available/ssl.load ssl.load
	    ln -s /etc/squirrelmail/apache.conf /etc/apache2/conf.d/squirrelmail.conf
	else
	    echo "/data/www/private/HTMLrequester/mod_auth_form-2.05 does not exist"
	fi

	##build DTNmail
	if [ -e /data/apps/DTNmailex/dtnmail ]; then
	    cd /data/apps/DTNmailex/dtnmail
	    echo "building DTNmail"
	    cp postfix/main.cf /etc/postfix/
	    cp postfix/master.cf /etc/postfix/
	    cp postfix/aliases /etc/postfix/
	    cp postfix/aliases.db /etc/postfix/
	    cp postfix/transport /etc/postfix/
	    cp postfix/transport.db /etc/postfix/
	    cp postfix/virtual.db /etc/postfix/
	    cp postfix/dynamicmaps.cf /etc/postfix/
	    cp dovecot/dovecot.conf /etc/dovecot/
	    cp dovecot/passwd.default /etc/dovecot/passwd
	    chmod 755 /etc/postfix/main.cf
	    cp etc/init.d/dtnmail* /etc/init.d/
	    chmod 755 /etc/init.d/dtnmail*
	    cp usr/local/bin/dtnmail* /usr/local/bin/
	    chmod 755 /usr/local/bin/dtnmail*
	    cp etc/squirrelmail/config.php /etc/squirrelmail/
	    cp usr/share/squirrelmail/images/n4c-logo.png /usr/share/squirrelmail/images/
	    touch /var/log/dovecot.log /var/log/dovecot-info.log
            chmod 755 /data/apps/DTNmailex/bin/*.php
            chown -R dtnuser:dtnuser /data/apps/DTNmailex/etc/*
	    chmod 666 /var/log/dovecot.log
	    chmod 666 /var/log/dovecot-info.log
	else
	    echo "/data/apps/DTNmailex does not exist"
	fi
    fi
fi
##end
cd /
