#!/bin/bash

## N4C router build script
## Alex McMahon 05/04/2010


bdir=`pwd`
disk="NULL"
part="NULL"
gwtype="NULL"
clear
echo ""
echo "Welcome to the N4C testbed node creator"
echo ""
echo "WARNING"
echo "This program will format disks !!"
echo ""


echo -n "Please provide http proxy ip and port number (IP:PORT) for apt and press [ENTER]: "
read proxy 
if [ "$proxy" == "" ]; then
    echo "proceeding without proxy"
else 
    echo "proxy to be used is $proxy"
    echo "Acquire::http::Proxy \"http://$proxy\";" >/etc/apt/apt.conf
    export http_proxy=$proxy
fi

echo -n "Please provide password for keys and certs and press [ENTER]: "
read password
if [ "$password" == "" ]; then
    echo "proceeding without certs/password ..stuff won't work"
else
    echo "once openssl is built this password will decrypt and decompress $bdir/enc"
fi

PS3="Choose (1-2):"
echo "Choose whether to build or reconfigure a N4C node from the list below."
select instype in build reconfigure
do

if [ "$instype" == "build" ]; then
PS3="Choose (1-3):"
echo "Choose an N4C node type to build from the list below."
select name in n4crouter n4cmule n4cgateway
do

	if [ "$name" == "n4crouter" ]; then
	PS3="Choose (1-5):"
	echo "Choose the $name number from the list below."
	select no in 1 2 3 4 5
	do
		break
	done

	elif [ "$name" == "n4cmule" ]; then
	PS3="Choose (1-5):"
	echo "Choose the $name number from the list below."
	select no in 1 2 3 4 5 
	do
		break
	done

	elif [ "$name" == "n4cgateway" ]; then
	PS3="Choose (1-2):"
	echo "Choose the $name number from the list below."
	select no in 1 2
	do
		break
	done

	elif [ "$no" = "" ]; then
	echo "Error in entry, please run script again."
        exit 1
	fi
	break
done
fi
break
done
echo "hostname is $name-$no"
echo "Unique EID is $name-$no.dtn"

if [ "$name" == "n4crouter" ]; then
echo $name-$no>/etc/hostname
hostname $name-$no
PS3="Choose (1-2):"
echo "Choose a platform from the list below."
select platform in proteus eeepc 
do

        if [ "$platform" == "proteus" ]; then
	    if [ -e /dev/mmcblk0 ]; then
		disk="/dev/mmcblk0"
		part="p1"
	    else 
		echo "the disk to be formatted does not exist... exiting"
	    exit 1
	    fi
	elif [ "$platform" == "eeepc" ]; then
	    if [ -e /dev/sdb ]; then
		disk="/dev/sdb"
		part="1"
            else
                echo "the disk to be formatted not exist... exiting"
            exit 1
            fi
	elif [ "$no" = "" ]; then
	echo "Error in entry, please run script again."
        exit 1
        fi
        break
done

elif [ "$name" == "n4cgateway" ]; then
echo $name-$no>/etc/hostname
hostname $name-$no
PS3="Choose (1-2):"
echo "Choose a gateway type from the list below."
select gwtype in gateway-basic gateway-router
do

        if [ "$gwtype" == "gateway-basic" ]; then
	    echo "you have selected $gwtype which will install a basic gateway"
	elif [ "$gwtype" == "gateway-router" ]; then
	    echo "you have selected $gwtype which will install a gateway router"
	else
	    echo "that is an incorrect selection"
	exit 1
	fi
        break
done

PS3="Choose (1-2):"
echo "Choose a platform from the list below."
select platform in proteus eeepc
do

        if [ "$platform" == "proteus" ]; then
            if [ -e /dev/mmcblk0 ]; then
                disk="/dev/mmcblk0"
                part="p1"
            else
                echo "the disk to be formatted not exist... exiting"
            exit 1
            fi
        elif [ "$platform" == "eeepc" ]; then
            if [ -e /dev/sdb ]; then
                disk="/dev/sdb"
                part="1"
            else
                echo "the disk to be formatted not exist... exiting"
            exit 1
            fi
        elif [ "$no" = "" ]; then
        echo "Error in entry...exiting."
        exit 1
        fi
        break
done

elif [ "$name" == "n4cmule" ]; then
PS3="Choose (1-3):"
echo "Choose a platform from the list below."
select platform in proteus eeepc WRAP
do

        if [ "$platform" == "proteus" ]; then
	echo $name-$no>/etc/hostname
	hostname $name-$no
            if [ -e /dev/mmcblk0 ]; then
                disk="/dev/mmcblk0"
                part="p1"
            else
                echo "$disk does not exist, exiting"
            exit 1
            fi
        elif [ "$platform" == "eeepc" ]; then
	echo $name-$no>/etc/hostname
	hostname $name-$no
            if [ -e /dev/sdb ]; then
                disk="/dev/sdb"
                part="1"
            else
                echo "$disk does not exist, exiting"
            exit 1
            fi
        elif [ "$platform" == "WRAP" ]; then
                disk="/dev/sda"
                part="3"
		hostname $name-$no
                ./create_disk.sh $disk $part $name
                ./create_dirs.sh $disk $part $name $gwtype $platform
                ./generate_configs.sh $disk $part $name $platform $gwtype $no
                ./update_rc.sh $name $platform $gwtype
	    reboot
        elif [ "$no" = "" ]; then
        echo "Error in entry, please run script again."
        exit 1
        fi
        break
done
fi
if [ "$instype" == "build" ]; then
echo "WARNING - the disk $disk will be formatted"
echo "Partition $disk$part will be mounted as /data"
echo -n "Do you wish to proceed .....? type yes to proceed: "
read proceed
if [ "$proceed" == "yes" ]; then
    echo "proceeding without proxy"
else
    echo "aborting"
    exit 1
fi

if [ "$disk" == "NULL" ]; then
echo  "proceeding without disk format"
else
echo "create data partition"
./create_disk.sh $disk $part $name
fi
echo "create directory structure"
./create_dirs.sh $disk $part $name $gwtype $platform
echo "get & install apt packages" 
./get_packages.sh $name $gwtype $platform
echo "clone hg code" 
./clone_it.sh $name $gwtype $gwtype
echo "build code"
./build_it.sh $name $bdir $password $gwtype
echo "load MySQL members schema" 
./load_schema.sh $name $gwtype
echo "generate configuration files" 
./generate_configs.sh $disk $part $name $platform $gwtype $no $password
echo "create rc" 
./update_rc.sh $name $platform $gwtype
echo "Build complete...rebooting"
sleep 2
reboot
elif [ "$instype" == "reconfigure" ]; then
echo "update sources"
./update_it.sh $name
echo "build code"
./build_it.sh $name $bdir $password $gwtype
echo "load MySQL members schema" 
./load_schema.sh $name $gwtype
echo "generate configuration files" 
./generate_configs.sh $disk $part $name $platform $gwtype $no $password
echo "create rc" 
./update_rc.sh $name $platform $gwtype
echo "Build complete...rebooting"
sleep 2
reboot
fi
