#!/usr/bin/tclsh
#
# Simple tcl script to generate an /etc/init.d/ script 
# for mail account adding daemon
#
# Common config for all nodes
#
set COMMON_CONFIG1 \
{
#!/bin/bash
### BEGIN INIT INFO
# Provides:          addaccounts.php
# Required-Start:    $remote_fs $syslog
# Required-Stop:     $remote_fs $syslog
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: N4C receive
### END INIT INFO

# Author: Stephen Farrell <stephen.farrell@cs.tcd.ie>
#
set -e

NAME=addaccount.php
DAEMON=/data/apps/DTNmailex/bin/$NAME
}

set COMMON_CONFIG2 \
{
DESC="addaccount"
PIDFILE=/var/run/$NAME.pid
SSD=`which start-stop-daemon`
SSDARGS="-u root -c root:root "
ENV="env -i LANG=C PATH=/bin:/usr/bin:/usr/local/bin"

test $DEBIAN_SCRIPT_DEBUG && set -v -x

trap "" 1

# Exit if the package is not installed
[ -x "$DAEMON" ] || exit 0

# Read configuration variable file if it is present
[ -r /etc/default/$NAME ] && . /etc/default/$NAME

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.0-6) to ensure that this file is present.
. /lib/lsb/init-functions

#
# Function that starts the daemon/service
#
should_start() {
    if [ ! -x $DAEMON ]; then
	echo "$NAME is not executable, not starting"
	exit 0
    fi
}

case "$1" in
  start)
    echo -n "Starting addaccount daemon..."
    should_start
    $SSD $SSDARGS --exec $DAEMON >> /var/log/dtn/addaccount.log 2>&1 --start -m --pidfile $PIDFILE -- $ARGS &
   ;;


  stop)
    echo -n "Stopping addaccount daemon..."
    $SSD $SSDARGS --stop --pidfile $PIDFILE || true
    rm -f $PIDFILE
    # kill children too
    kpids=`pgrep -f addmailaccount`
    echo "Killing children: $kpids"
    kill -9 $kpids
    ;;

  restart)
    echo -n "Stopping addaccount daemon..."
    $CONTROL stop || true
    echo -n "Making sure addaccount daemon stops..."
    $SSD $SSDARGS --stop --pidfile $PIDFILE || true
    # kill children too
    kpids=`pgrep -f addmailaccount`
    echo "Killing children: $kpids"
    kill -9 $kpids
    echo -n "Restarting addaccount daemon..."
    $SSD $SSDARGS --exec $DAEMON >> /var/log/dtn/addaccount.log 2>&1 --start -m --pidfile $PIDFILE -- $ARGS &
    ;;

  *)
    echo "Usage: /etc/init.d/$NAME {start|stop|restart}"
    exit 1
    ;;
esac

}


# generate the config
puts "#\n# Configuration generated [clock format [clock seconds]]\n#"
puts $COMMON_CONFIG1
puts ""
puts $COMMON_CONFIG2

