#!/usr/bin/tclsh
#
# Simple tcl script to generate a static topology of dtn links and
# routes for a network.
#
set filename "topology.tcl"
source $filename
set filename "links-smartbay.tcl"
source $filename
#
# Common config for all nodes
#
set COMMON_CONFIG \
{
set localhost [lindex [split [info hostname] .] 0]
console set prompt "$localhost dtn% "
console set addr 127.0.0.1
console set port 5050

storage set type       filesysdb
storage set payloaddir /data/dtn/payload
storage set dbname     DTN
storage set dbdir      /data/dtn/storage
param set link_min_retry_interval 1
param set link_max_retry_interval 10
param set custody_timer_lifetime_pct 1

interface add tcp0 tcp local_port=4556
# Rotate the log every 24 hours (86400000 seconds)
# the initial call to rotate (after the proc) is required to
# start the proc running every hour.
proc rotate {} {
    set date [ clock format [ clock seconds ] -format "%Y-%m-%d-%H%M%S" ]
    set new "dtnd.$date.log"
    file rename "/var/log/dtn/dtnd.log" /data/dtn/log/$new

    log rotate

    after 86400000 rotate
}
rotate
}

#-----------------------------------------------------------------------------
#
# Graph IMPLEMENTATION STARTS HERE
#


#
# first build the list of all hosts
#
set allhosts [array names addr]
foreach h $links {
    set h [lindex [split $h ,] 0]
    if {[lsearch $allhosts $h] == -1} {
        lappend allhosts $h
    }
}

# build a full_links list as {host1 addr1 host2 addr2} quads
set l2 {}
foreach link $links {
    foreach {h a} [split $link ,] {}
    if {$a == ""} {
        if {! [info exists addr($h)] || [llength $addr($h)] > 1} {
            error "need unique address specifcation for host $h in link {$src - $dst}"
        }
        set a $addr($h)
    }

    lappend l2 $h
    lappend l2 $a
}
set links $l2
        
# find all reachable nodes starting from the link src -> dst
proc reachable {src dst} {
    set visited $src
    reachable2 visited $dst
    return $visited
}
proc reachable2 {visitedVar host} {
    upvar $visitedVar visited
    global links
    lappend visited $host
    foreach {host1 addr1 host2 addr2} $links {
        if {$host1 == $host && [lsearch $visited $host2] == -1} {
            reachable2 visited $host2
        } elseif {$host2 == $host && [lsearch $visited $host1] == -1} {
            reachable2 visited $host1
        }
    }
}

# proc to return the link options between two hosts
proc link_opts {parent child} {
    return ""
}

# generate the config
puts "#\n# DTN Configuration generated [clock format [clock seconds]]\n#"
puts $COMMON_CONFIG
	if {$type == "n4crouter"} {
		puts "route set type static"
                puts "route set open_discovered_links false"
                puts "route set add_nexthop_routes false"
#                puts "route set open_discovered_links true"
#                puts "discovery add tcp0d ip port=9556"
#                puts "discovery announce tcp0 tcp0d tcp interval=10"
	} elseif {$type == "n4cgateway"} {
                puts "route set type static"
		puts "route set open_discovered_links false"
                puts "route set add_nexthop_routes false"
        } elseif {$type == "n4cmule"} {
                puts "route set type static"
                puts "route set open_discovered_links false"
                puts "route set add_nexthop_routes false"
	} else {
		puts "route set type static"
                puts "route set open_discovered_links false"
                puts "route set add_nexthop_routes false"

	}


puts "switch -exact \$localhost \{"
foreach host [lsort $allhosts] {
    puts "  $host \{"
    puts "    route local_eid dtn://$host.dtn"
    foreach {host1 addr1 host2 addr2} $links {
        if {$host == $host1} {
            set dst      $host2
            set dst_addr $addr2
            set type     ALWAYSON
        } elseif {$host == $host2} {
            set dst      $host1
            set dst_addr $addr1
            set type     ALWAYSON
        } else {
            continue
        }
        
	
        puts "    link add l-$dst $dst_addr:4556 $type tcp [link_opts $host $dst]"
            foreach n [reachable $host $dst] {
	    if {$host != $n  
			&& [lindex [split $host -] 0] == "n4crouter"} {
			        if {$n == $dst} {
                                        puts "    route add dtn://$n.dtn l-$dst"
					puts "    route add dtn://$n.dtn/* dtn://$dst.dtn"
                                } else {
                                        if {([lindex [split $n -] 0] != "n4cmule")} {
        #                                puts "    route add dtn://$n.dtn/* dtn://$dst.dtn"
                                        }
                                        }
            } elseif {$host != $n  
			&& [lindex [split $host -] 0] == "n4cgateway" 
			&& ($n == $dst 
			|| (([lindex [split $n -] 0] == "n4crouter") 
			&& $dst != "basil.dsg.cs.tcd.ie"))} {
                                if {$n == $dst} {
        #                                puts "    route add dtn://$n.dtn l-$dst"
					    if {[lindex [split $dst -] 0] != "n4cmule"} {
					    } else {
                                        puts "    route add dtn://$n.dtn l-$dst"
                                        puts "    route add dtn://$n.dtn/* dtn://$dst.dtn"
						}
                                } else {
                                        puts "    route add dtn://$n.dtn/* dtn://$dst.dtn"
                                        } 
            } elseif {$host != $n 
			&& [lindex [split $host -] 0] 
			== "n4cmule" 
			&& ($n == $dst 
			|| ($n == "basil.dsg.cs.tcd.ie" 
			&& ([lindex [split $dst -] 0] == "n4cgateway")))} {
				if {($n == "basil.dsg.cs.tcd.ie" 
					&& ([lindex [split $dst -] 0] == "n4cgateway"))} {
					puts "    route add dtn://$n.dtn/* dtn://$dst.dtn"
				} else { 
					puts "    route add dtn://$n.dtn/* l-$dst"
                                            if {[lindex [split $dst -] 0] == "n4crouter"} {
                                        puts "    route add dtn://$n.dtn l-$dst"
                                        puts "    route add dtn://$n.dtn/* dtn://$dst.dtn"

                                            } else {
                                                }

					}
            } elseif {$host != $n 
			&& $host == "landside"} {
                                if {$dst == $n} {
                                        puts "    route add dtn://$n.dtn l-$dst" 
					puts "    route add dtn://$n.dtn/* dtn://$dst.dtn"
                                } elseif {([lindex [split $n -] 0] != [lindex [split $dst -] 0])} {
                                        }
	    }
        }
    }
    puts "  \}"
}
puts "\}"

    
