#!/usr/bin/tclsh
#
#
# Common config for all nodes
#
set COMMON_CONFIG \
{
#!/bin/bash
### BEGIN INIT INFO
# Provides:          dtnd
# Required-Start:    $remote_fs $syslog
# Required-Stop:     $remote_fs $syslog
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: DTN2
# Description:       This file should be used to construct scripts to be
#                    placed in /etc/init.d.
### END INIT INFO

# Author: Alex McMahon <alex.mcmahon@cs.tcd.ie>
#
set -e
NAME=dtnd
DAEMON=/usr/bin/$NAME
DESC="Description of the service"
CONTROL=/usr/bin/$NAME-control
ARGS="-d -l info -o /var/log/dtn/dtnd.log"
PIDFILE=/var/run/$NAME.pid
SSD=`which start-stop-daemon`
SSDARGS="-u dtnuser -c dtnuser:root --exec $DAEMON"
ENV="env -i LANG=C PATH=/bin:/usr/bin:/usr/local/bin"
SCRIPTNAME=/etc/init.d/$NAME

test $DEBIAN_SCRIPT_DEBUG && set -v -x

trap "" 1
# Exit if the package is not installed
[ -x "$DAEMON" ] || exit 0

# Read configuration variable file if it is present
[ -r /etc/default/$NAME ] && . /etc/default/$NAME

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.0-6) to ensure that this file is present.
. /lib/lsb/init-functions

#
# Function that starts the daemon/service
#


case "$1" in
  start)
    echo -n "Starting DTN daemon..."
    $SSD $SSDARGS --start -m --pidfile $PIDFILE -- $ARGS
    pgrep -f "$NAME">$PIDFILE
    ;;

  start_tidy)
    echo -n "Starting DTN daemon (tidy mode)..."
    $SSD $SSDARGS --start -m --pidfile $PIDFILE -- $ARGS -t
    pgrep -f "$NAME">$PIDFILE
    ;;

  stop)
    echo -n "Stopping DTN daemon..."
    $CONTROL $CONTROLARG stop || true
    echo -n "Making sure DTN daemon stops..."
    $SSD $SSDARGS --stop --pidfile $PIDFILE || true
    rm -f $PIDFILE
    ;;

  restart)
    echo -n "Stopping DTN daemon..."
    $CONTROL $CONTROLARG stop || true
    echo -n "Making sure DTN daemon stops..."
    $SSD $SSDARGS --stop --pidfile $PIDFILE || true
    echo -n "Restarting DTN daemon..."
    $SSD $SSDARGS --start -m --pidfile $PIDFILE -- $ARGS
    pgrep -f "$NAME">$PIDFILE
    ;;

  logrotate)
    echo -n "Rotating logs for DTN daemon..."
    $CONTROL $CONTROLARG logrotate
    ;;

  *)
    echo "Usage: /etc/init.d/$NAME {start|start_tidy|stop|restart|logrotate}"
    exit 1
    ;;
esac
}


# generate the config
puts "#\n# Configuration generated [clock format [clock seconds]]\n#"
puts $COMMON_CONFIG

