#!/usr/bin/tclsh
#
set filename "topology.tcl"
source $filename
#
set COMMON_CONFIG1 \
{
#!/bin/bash
### BEGIN INIT INFO
# Provides:          dtnrecv
# Required-Start:    $remote_fs $syslog
# Required-Stop:     $remote_fs $syslog
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: N4C receive
### END INIT INFO

# Author: Alex McMahon <alex.mcmahon@cs.tcd.ie>
#
set -e

NAME=dtnrecv
DAEMON=/usr/bin/$NAME
}

set COMMON_CONFIG2 \
{

test $DEBIAN_SCRIPT_DEBUG && set -v -x

trap "" 1


# Exit if the package is not installed
[ -x "$DAEMON" ] || exit 0

# Read configuration variable file if it is present
[ -r /etc/default/$NAME ] && . /etc/default/$NAME

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.0-6) to ensure that this file is present.
. /lib/lsb/init-functions

#
# Function that starts the daemon/service
#
should_start() {
    if [ ! -x $DAEMON ]; then
	echo "$NAME is not executable, not starting"
	exit 0
    fi
}

case "$1" in
  start)
    echo "Starting dtnrecv daemon..."
    should_start
    $SSD $SSDARGS --start -m --pidfile $PIDFILE >> /var/log/dtn/dtnrecv.log 2>&1 -- $ARGS &
    pgrep -f "$REG">$PIDFILE
    ;;


  stop)
    echo  "Stopping dtnrecv daemon..."
    $SSD $SSDARGS --stop --pidfile $PIDFILE || true
    rm -f $PIDFILE


    ;;

  restart)
    echo "Stopping dtnrecv daemon..."
    echo "Making sure dtnrecv daemon stops..."
    $SSD $SSDARGS --stop --pidfile $PIDFILE || true
    echo "Restarting dtnrecv daemon..."
    $SSD $SSDARGS --start -m --pidfile $PIDFILE >> /var/log/dtn/dtnrecv.log 2>&1 -- $ARGS &

    pgrep -f "$REG">$PIDFILE
    ;;

  *)
    echo "Usage: /etc/init.d/$NAME {start|stop|restart}"
    exit 1
    ;;
esac

}


# generate the config
puts "#\n# Configuration generated [clock format [clock seconds]]\n#"
puts $COMMON_CONFIG1
puts "ARGS=\" -p transaction_####.tar.gz dtn://$localhost.dtn/HTMLrouter\""
puts "DESC=\"dtnrecv\""
puts "PIDFILE=/var/run/\$NAME.pid"
puts "SSD=`which start-stop-daemon`"
puts "SSDARGS=\"-u root -c root:root --exec \$DAEMON\""
puts "ENV=\"env -i LANG=C PATH=/bin:/usr/bin:/usr/local/bin\""
puts "REG=\"/usr/bin/dtnrecv -p transaction_####.tar.gz dtn://$localhost.dtn/HTMLrouter\""
puts $COMMON_CONFIG2

