#!/usr/bin/tclsh
#
set COMMON_CONFIG \
{
# dtnmailsyncs
#
# Sends out a mail sync bundle from $NODE to all other nodes in the network
#

NODE=`uname -n`
DEST_EID[0]="dtn://basil.dsg.cs.tcd.ie.dtn/mailsync"
DEST_EID[1]="dtn://n4crouter-1.dtn/mailsync"
DEST_EID[2]="dtn://n4crouter-2.dtn/mailsync"
DEST_EID[3]="dtn://n4crouter-3.dtn/mailsync"
DEST_EID[4]="dtn://n4crouter-4.dtn/mailsync"
DEST_EID[5]="dtn://n4crouter-5.dtn/mailsync"
DEST_EID[6]="dtn://n4cgateway-1.dtn/mailsync"
DEST_EID[7]="dtn://n4cgateway-2.dtn/mailsync"

SRC_EID="dtn://$NODE.dtn/mailsync"
WORKING_DIR="/data/dtn/dtnmailex"
LAST_SYNC="$WORKING_DIR/time.log"

function log {
    echo "`date -R` $NODE $DAEMON $1" >> /var/log/dtn/$DAEMON.log
}
DAEMON="dtnmailsyncsd"

while [ 1 ]; do

   log "Beginning mail sync process"

   timenow=`date +"%H:%S"`
   secnow=`date +"%s"`

   hourtowake="08:00"

   if [ $timenow \> "08:00" ]
   then
       sectowake=`date -d "tomorrow $hourtowake" +"%s"`
       timetowake=`date -d "tomorrow $hourtowake"`
   else
       sectowake=`date -d "$hourtowake" +"%s"`
       timetowake=`date -d "$hourtowake"`
   fi

   sleepsec=$(( $sectowake - $secnow ))

   cd $WORKING_DIR

# Format of an imap filename is
# 9999999.9999999.nodename,S=999,W=999:2,FLAGS
# +----------------------+
# This bit is unique up to the first ","

    directory=/data/dtn/dtnmailex
    newlist=$directory/$NODE-newlist
    oldlist=$directory/$NODE-oldlist
    renamefiles=$directory/$NODE-renamefiles
    deletefiles=$directory/$NODE-deletefiles
    addfiles=$directory/$NODE-addnewfiles
    mailsyncfile=$directory/$NODE-mailsync.tar

    rm -f $addfiles
    rm -f $mailsyncfile

    echo -n > $renamefiles
    echo -n > $deletefiles

    log "Check for renamed or deleted files ..."

    # Check if $oldlist not there, then this is the first run
    # Make sure the files are empty (rather than just touch)

    if [ ! -f "$oldlist" ];then
       echo -n > $oldlist
    fi

    # Read from $oldlist for each line do ...
    # ... if file exists do nothing
    # ... if file does not exist
    # ...  if its filename has changed, add to rename list
    # ...  its not there so it must be deleted , add to delete list

    while read line; do
   
     if [ ! -f "$line" ];then
          index=`expr index $line ","` || index=$(( ${#line} + 1 ))
                                # look for first ","
          lineunique=${line:0:$index-1} # extract up to ","

          newline=`ls $lineunique* 2> /dev/null`
          if [ "$?" -eq "0" ];then
              echo $newline >> $renamefiles
          else
              echo $line >> $deletefiles
          fi
       fi

    done < $oldlist


# Now do new files
# Get a list of all files and check if each one is on the oldlist. If its
# not then its a new file, so the whole file has to be sent.

    find /data -path "/data/dtn/mail/*/maildir/???/*.*.$HOSTNAME*" > $newlist

    log "Checking for new files ..."

    while read line; do
         index=`expr index $line ","`  || index=$(( ${#line} + 1 ))
                           # look for first "," default to length if non found
         lineunique=${line:0:$index-1} # extract up to ","
         grep $lineunique $oldlist > /dev/null || echo $line >> $addfiles

    done < $newlist

# Here we add the renamefile list and the deletefile list to the list of files
# to put in the tar bundle.

    echo $renamefiles >> $addfiles
    echo $deletefiles >> $addfiles

    tar -cf $mailsyncfile -T $addfiles

    if [ "$?" -ne "0" ];then
       log "Problem creating tar file $mailsync - error $?"
    fi
# Check if there is nothing to sync - an empty mail sync tar bundle is just
# 10240 bytes in size. Anything bigger means we have a sync

filesize=`du -b $mailsyncfile | awk '{print $1}'`

if [ $filesize -gt 10240 ]; then

# Now transmit the bundle

        #DTN-SEND
        # Send as payload file -t f
        # Payload data is the file -p
        # Set no fragment -W
        # set expire time in sec -e (5 days)
        # -c transfer custody 

# Send the update file to all other nodes EXCEPT this one of course!

    for ((i=0;i<=7;i+=1)); do

       if [[ ${DEST_EID[i]} != *$NODE* ]]
       then
          log "Sending update bundle to ${DEST_EID[i]}"
          dtnsend -v -e 432000 -W -s $SRC_EID -d ${DEST_EID[i]} -t f -p $mailsyncfile >> /var/log/dtn/$DAEMON.log
             # Check if dtnsend worked - if not, delete the newlist file
             # The oldlist will still be valid when next update runs
          if [ "$?" -ne "0" ];then
             log "Problem invoking dtnsend - error $?"
             rm -f $newlist
          fi
       fi
    done

# if $newlist is not there, then there was a problem with dtnsend so keep
# the oldlist

    if [ -f "$newlist" ]; then
        cp $newlist $oldlist
    fi

else
    log "Empty sync file - not sending"
fi

# Now sleep for the required time

   log "Sleeping for $sleepsec until $timetowake"
   /bin/sleep $sleepsec

done


}
# generate the config
puts "#!/bin/bash"
puts $COMMON_CONFIG
