#!/usr/bin/tclsh
#
set filename "topology.tcl"
source $filename

# need to include protus gateway
if {$type == "n4crouter"} {

    set sed_script  "/data/www/statichtml/sed.sh"
    set battery_log "/var/log/battery.log"
    set battery_csv "/var/log/battery.csv"
    set image_path  "/data/www/statichtml/images/"

    puts "#!/bin/bash"
    puts "#\n# Gnuplot script generated [clock format [clock seconds]]\n#"

    puts "if \[ ! -f $battery_log \]; then"
    puts "    echo \"ERROR: $battery_log not found\""
    puts "    exit 1"
    puts "fi"
    puts "if \[ ! -d $image_path  \]; then"
    puts "    echo \"ERROR: $image_path not found\""
    puts "    exit 1"
    puts "fi"

    puts "#\n# set date range for: day | week | all\n#"
    puts "START_ALL=\"2011-04-01 00:00:00\""
    puts "START_DAY=\"`date +%Y-%m-%d\\ %H:%M:%S --date=\"-2 day\"`\""
    puts "START_WEEK=\"`date +%Y-%m-%d\\ %H:%M:%S --date=\"-7 day\"`\""
    puts "END=\"`date +%Y-%m-%d\\ %H:%M:%S`\""

    puts "#\n# update battery.csv\n#"
    puts "if \[  -f $battery_csv \]; then"
    puts "    cp -f $battery_csv .foo"
    puts "else"
    puts "    touch .foo"
    puts "fi"
    puts "$sed_script $battery_log > .bar"
    puts "cat .foo .bar | sort -u > $battery_csv"
    puts "rm -f .foo .bar"
    
    puts "#\n# plot (start_time, image_name)\n#"
    puts "function plot {"
    puts "gnuplot -noraise <<-finish"
    puts "    set terminal png nocrop enhanced size 1300,800"
    puts "    set output '\$2'"
    puts "    set datafile separator \",\""
    puts "    set xdata time"
    puts "    set timefmt \"%Y-%m-%d %H:%M:%S\""
    puts "    set title \"Router Power\""
    puts "    set key below"
    puts "    set bmargin 3 "
    puts "    spike=1"
    puts "    set xrange  \[ \"\$1\" : \"\$END\" \]"
    puts "    set yrange  \[ 1500:15000\]"
    puts "    set y2range \[-6000:8000 \]"
    puts "    set ytics  ( 15000, 14000, 13000, 12000, 11000,\"spike\" 10050, 9000, 8000, 7000, 6000,\"OVERRIDE\" 5000,\"UP\" 4500,\"STBYSHORT\" 4000,\"STBYLONG\" 3500,\"SLEEP\" 3000,\"OFF\" 2500 )"
    puts "    set y2tics ( 4000, 3500, 3000, 2500, 2000, 1500, 1000, 500, 0, -500, \"spike\" -1000 )"
    puts "    set pointsize 0.3"
    puts "    plot '$battery_csv' using 1: ( (\\\$7 == spike) ? 10050 : (10 * \\\$4) ) axes x1y1 title \"mV\" with points, \\"
    puts "         '$battery_csv' using 1: ( (\\\$7 == spike) ?   -50 :       \\\$5  ) axes x1y2 title \"mA\" with points, \\"
    puts "         '$battery_csv' using 1: ( (2000 + \\\$6) ) axes x1y1 title \"state\" with step"
    puts "finish"
    puts "}"

    puts "#\n# create images\n#"
    puts "plot \"\$START_DAY\"  \"power_day.png\""
    puts "plot \"\$START_WEEK\" \"power_week.png\""
    puts "plot \"\$START_ALL\"  \"power_all.png\""

    puts "#\n# move images\n#"
    puts "mv -f power_day.png  $image_path"
    puts "mv -f power_week.png $image_path"
    puts "mv -f power_all.png  $image_path"

    puts "exit 0"
}

