#!/usr/bin/tclsh
#
# Simple tcl script to generate a static topology of dtn links and
# routes for a network.
set addr(basil.dsg.cs.tcd.ie)   192.168.1.102
set addr(n4cgateway-1)          10.125.14.10
set addr(n4cgateway-2)          10.125.14.11
set addr(n4crouter-1)           10.125.14.12
set addr(n4crouter-2)           10.125.14.13
set addr(n4crouter-3)           10.125.14.14
set addr(n4crouter-4)           10.125.14.15
set addr(n4crouter-5)           10.125.14.16
set addr(n4cmule-1)             10.125.14.17
set addr(n4cmule-2)             10.125.14.18
set addr(n4cmule-3)             10.125.14.19
set addr(n4cmule-4)             10.125.14.20
set addr(n4cmule-5)             10.125.14.21

set id [lindex $argv 0]
set localhost [lindex [split [info hostname] .] 0]
set ip $addr([lindex [split [info hostname] .] 0])
set type [lindex [split [info hostname] -] 0]

#
# Common config for all nodes
#
set COMMON_CONFIG \
{

######################
## Create mesh mp 
######################
start_mesh () {
echo "adding $MESH_IFACE type $TYPE mesh_id $MESH_ID"
iw dev $IFWIRELESS interface add $MESH_IFACE type $TYPE mesh_id $MESH_ID
echo "bringing up $MESH_IFACE"
ifconfig $MESH_IFACE up
echo "scanning with $MESH_IFACE"
iw dev $MESH_IFACE scan
#echo "setting type to $TYPE on $MESH_IFACE"
#iw dev $MESH_IFACE set type $TYPE
#echo "setting meshid to $MESH_ID on $MESH_IFACE"
#iw dev $MESH_IFACE set meshid $MESH_ID
echo "setting channel to $CHANNEL of $MESH_IFACE"
iw dev $MESH_IFACE set channel $CHANNEL
echo "configuring $MESH_IFACE with $IP and netmask $NETMASK and bringing up"
ifconfig $MESH_IFACE $IP netmask $NETMASK
#echo "setting mesh_param mesh_auto_open_plinks of $MESH_IFACE"
#iw dev $MESH_IFACE set mesh_param mesh_auto_open_plinks 1
#iw dev $MESH_IFACE get mesh_param mesh_auto_open_plinks
}
######################
## tear down mesh mp 
######################
stop_mesh () {
ifconfig $MESH_IFACE down
#ifconfig $MESH_IFACE down
iw dev $MESH_IFACE del
#iw dev $IFWIRELESS del
#ifconfig $MESH_IFACE down
}

######################
## Status mesh mp
######################
status_mesh () {
ifconfig -a|grep mesh
arp
iw dev $MESH_IFACE station dump
iw dev $MESH_IFACE mpath dump
}

#################################
# Set up Ethernet bridge on Linux
# Requires: bridge-utils
#################################
start_bridge () {
brctl addbr $BRIDGE
brctl stp $BRIDGE off
brctl addif $BRIDGE $IFLAN
brctl addif $BRIDGE $MESH_IFACE
ifconfig $MESH_IFACE down
ifconfig $IFLAN down
ifconfig $MESH_IFACE 0.0.0.0 up
ifconfig $IFLAN up
ifconfig $BRIDGE $IP
}

stop_bridge () {
ifconfig $BRIDGE down
ifconfig $IFLAN down
brctl delif $BRIDGE $IFLAN
brctl delif $BRIDGE $MESH_IFACE
}

case "$1" in
start)
echo -n "Starting Mesh"
start_mesh
#echo -n "Starting Bridge"
#start_bridge
;;
stop)
echo -n "Stopping Mesh"
stop_mesh
#echo -n "Stopping Bridge"
#stop_bridge
;;
restart)
stop_mesh
#stop_bridge
sleep 2
start_mesh
#start_bridge
;;
status)
status_mesh
;;
*)
echo "Usage: $0 {start|stop|restart|status}" >&2
exit 1
;;
esac
}
# generate the config
puts "#\n# Configuration generated [clock format [clock seconds]]\n#"
if {$type == "n4crouter"} {
puts "#!/bin/bash"
puts "IFWIRELESS=wlan0"
puts "PHY=phy0"
puts "IFLAN=eth0"
puts "MESH_IFACE=mesh0"
puts "CHANNEL=1"
puts "IP=$ip"
puts "MESH_ID=N4CmeshInterface"
puts "NETMASK=255.255.255.0"
puts "TYPE=mp"
puts "BRIDGE=br0"
puts $COMMON_CONFIG
    } elseif {$type == "n4cgateway"} {
    } elseif {$type == "n4cmule"} {
	if {$id == "WRAP"} {
	} else {
	}
}
